@@ -150,7 +150,8 @@ class CommunityProfilePermissions(CommunityPermissions):
             from djangoldp_community.models import Community
             resolved = resolve(request.path_info)
             if 'slug' in resolved.kwargs and (resolved.url_name == "community-communityprofile-list" or\
-                resolved.url_name == "community-communityprofile-detail" or resolved.url_name == "community-detail"):
+                resolved.url_name == "community-communityprofile-detail" or resolved.url_name == "community-detail")\
+                or resolved.url_name == "community-communityaddress-list":
                 community = Community.objects.get(slug=resolved.kwargs['slug'])
                 if is_authenticated_user(request.user) and community.members.filter(user=request.user).exists():
                     if community.members.get(user=request.user).is_admin:
